Welcome to altimetry tools’s documentation! — altimetry tools 0 documentation

### Navigation

- index
- modules |
- next |
- altimetry tools 0 documentation »

# Welcome to altimetry tools’s documentation!

## Description

py-altimetry is a python module made to easily handle and process altimetry data. It can furthermore handle a wider variety of data (in-situ or imagery data), and also has a number of tools, eg. spectral analysis, filtering data, interpolating, plotting maps, handle date vectors, handle positional data ...

This is module can be used as is, and is not aimed (nor designed) for operationnal constraints.

## Contents

- 1. Description of the modules
- 2. Some examples to illustrate py-altimetry functionalities
- 3. Install, configure & modify

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- altimetry tools 0 documentation »